@@ -15,7 +15,6 @@ sub initialize {
     $self->{defined}{ArchiveName}       =   'nginx';
     $self->{defined}{WebSite}           =   'http://nginx.org';
     $self->{defined}{VersionForm}       =   '1\.\d\.\d{1,2}';
-    $self->{defined}{Extension}         =   'tar.gz';
     $self->{defined}{DownloadSite}      =   'http://nginx.org/download/';
     
     $self->{defined}{AdditionalArgument}=   \&set_argument;
@@ -62,3 +61,24 @@ sub set_argument {
 
 1;
 
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Nginx - definition module for nginx
+
+=head1 SEE ALSO
+
+L<nginx|http://nginx.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
