@@ -13,7 +13,6 @@ sub initialize {
     $self->{defined}{ArchiveName}       =   'openssl';
     $self->{defined}{WebSite}           =   'http://www.openssl.org/';
     $self->{defined}{VersionForm}       =   '\d\.\d\.\d\w?';
-    $self->{defined}{Extension}         =   'tar.gz';
     $self->{defined}{DownloadSite}      =   'http://www.openssl.org/source/';
 
     $self->{defined}{AdditionalArgument}=   \&set_argument;
@@ -47,3 +46,25 @@ sub set_sorted_version_list {
 }
 
 1;
+
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Openssl - definition module for OpenSSL
+
+=head1 SEE ALSO
+
+L<OpenSSL|http://www.openssl.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
