@@ -10,19 +10,13 @@ sub initialize {
     
     $self->SUPER::initialize;
     
-    $self->{defined}{ArchiveName}       =   'zsh';
-    $self->{defined}{WebSite}           =   'http://www.zsh.org';
-    $self->{defined}{VersionForm}       =   '\d\.\d\.\d';
-    $self->{defined}{Extension}         =   'tar.gz';
-    $self->{defined}{DownloadSite}      =   'http://sourceforge.net/projects/zsh/files/zsh/';
+    $self->{defined}{ArchiveName}     = 'zsh';
+    $self->{defined}{WebSite}         = 'http://www.zsh.org';
+    $self->{defined}{VersionForm}     = '\d\.\d\.\d';
+    $self->{defined}{DownloadSite}    = 'http://sourceforge.net/projects/zsh/files/zsh/';
 
-    $self->{defined}{IndexParserForm}   =   \&set_index_parser_form;
-    $self->{defined}{URL}               =   \&set_URL;
-
-    $self->{defined}{CommandConfigure}  =   './configure';
-    $self->{defined}{CommandMake}       =   'make';
-    $self->{defined}{CommandTest}       =   undef;
-    $self->{defined}{CommandInstall}    =   'make install';
+    $self->{defined}{IndexParserForm} = \&set_index_parser_form;
+    $self->{defined}{URL}             = \&set_URL;
 
     return $self;
 }
@@ -50,6 +44,26 @@ sub set_URL {
     return $url;
 }
 
-
 1;
 
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Zsh - definition module for Zsh
+
+=head1 SEE ALSO
+
+L<Zsh|http://www.zsh.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
